---
title: Activity relevance in the Global Commoning System
date: 2020-03-10
---

# Introduction

Activities can be sorted by calculating a relevance for each. The relevance of an activity varies from user to user, as therefore does the sorting order.

Relevance is differentiated into multiple aspects according to the following tree:

```mermaid
graph TD;
    r[relevance];
    p[personal relevance];
    s[systemic relevance];
    c[circumstances];
    a[acknowledgements];
    sr[social relationships];
    ADV1((ADV 1));
    ADV2((ADV 2));
    ADVn((ADV n));
    ADVs1((ADVs));
    ADVs2((ADVs));
    ADVs3((ADVs));

    r --- p;
    p --- c;
    c --- ADV1;
    c --- ADV2;
    c -.- ADVn;
    p --- a;
    a -.- ADVs1;
    p --- sr;
    sr -.- ADVs2;

    r --- s;
    s -.- ADVs3;
```

__Personal relevance__ includes aspects that consider the person whose wish is made possible by completing the activity in question and that contribute to to a perception of fairness, whereas __systemic relevance__ includes matters of efficiency and ability and that, if at all, depend on the person that completes the activity.

__Circumstances__ refer to the person whose wish is made possible by completing the activity in question. They are defined by the community and, among other things, may include number of children or level of education.

__Acknowledgements__ also refer to the person whose wish is made possible by completing the activity in question. They are defined by the community and include public recognitions of achievements.

__Social relationships__ refer to the connection between the person that completes the activity and the person whose wish is made possible by completing the activity in question. They are defined by the community and, among other things, may include the status of friendships or kinship.

__Systemic relevance__ may include things such as

- spatial proximity between the destination and the location of the person that completes the activity
- temporal proximity between the desired date of completion and the current date
- repeated necessity of the activity
- abilities of the person that completes the activity

Increasing numerical values of terminal aspects (located at the leafs in the tree above) may either increase or decrease the user's preference of the activity. For each terminal aspect, users can also provide their understanding of what makes a pronounced manifestation of that aspect and what makes a medium manifestation. Terminal aspects exceeding the medium manifestation will result in a non-linear (sigmoidal) increase of relevance and vice versa.

# Mathematical description

For the purpose of relevance calculation, branching in the figure above denotes a weighted sum, where weights are adjustable by users. Leafs ("attribute derived values") have a domain between $0$ and $1$ and can be calculated from attributes. The following discussion assumes that exactly one person benefits from the completion of the activity. If multiple people benefit from the completion of the activity, the arithmetic mean is calculated for the personal relevance across all beneficiaries.

The relevance $r$ of an activity has two **c**omponents. It is the weighted sum of a **p**ersonal and a **s**ystemic relevance with individual weight $w_{c}$:

$$
r = \sum_{c \in C} w_{c} \cdot r_{c} \quad \text{with} \quad \lvert C \rvert = 2,\; \sum_{w_{c}} = 1
$$

The personal relevance $r_{p}$ is comprised of three **f**acets – circumstances, acknowledgement and social relationships – yielding another individually weighted sum:

$$
r_p = \sum_{f \in F} w_{f} \cdot r_{f} \quad \text{with} \quad \lvert F \rvert = 3,\; \sum_{w_{f}} = 1
$$

There may be multiple community defined **a**ttributes for each facet, for example:

| Facet                | Attributes (exemplary selection)                                        |
| -------------------- | ----------------------------------------------------------------------- |
| Circumstances        | number of children, level of education                                  |
| Acknowledgements     | reputation on stackoverflow.com, number of compliments on gutefrage.net |
| Social relationships | friend of, family member of                                             |

Similarly, there may be multiple attributes for the systemic relevance $r_s$, for example the activity's spatial and temporal proximity.

Each attribute has a **p**olarity $p_{a}$ of $+1$ or $-1$, where the former indicates that the attribute is directly proportional to the user's preference and the latter indicates that the attribute is inversely proportional to the user's preference.

Attributes (**t**erminal aspects) contribute to the calculation of a superior node through their _attribute derived values_ $v_a$, again via a weighted sum:

$$
r_{t} = \sum_{a \in A} w_{a} \cdot v_{a} \quad \text{with} \quad \sum_{w_{a}} = 1,\; v_{a} \in \left] 0, 1 \right[
$$

The mapping between an attribute $a$ of polarity $p_{a}$ and its derived value $v_{a}$ is provided by the following logistic function:

$$
v_{a} = \frac{p_{a}}{1+\exp\left( -k \cdot (a-x_{0}) \right)} + s_{p}
$$

with $a, k, x_{0} \in \mathbb{R},\; p_{a} \in \{-1, +1\}$ and $s_{p} \coloneqq -0.5 \cdot (\mathrm{sgn}(p_{a})-1)$ satisfying

$$
s_{p} = \begin{cases}1, & \text{if } p_{a} = -1\\ 0 & \text{otherwise}\end{cases}
$$

For $k = 1, x_{0} = 0, p_{a} = +1$ the logistic function looks as follows:

![The logistic sigmoid function](https://upload.wikimedia.org/wikipedia/commons/8/88/Logistic-curve.svg)

Given $y, z \in \mathbb{R}$ by the user with

$$
v_{y} = 0.5,\; v_{z} = 0.9
$$

it follows that

$$
x_{0} = y, k = \frac{-\ln\left( \frac{p_{a}}{0.9 - s} - 1 \right)}{z-y}
$$

# User interface

The specification above demands two different kinds of user input:

- distributing importance (weight) across co-ordinate aspects
- choosing a medium and a pronounced manifestation of terminal aspects

Ideally they are part of an integrated interface that corresponds to the tree in above's figure.

# Default values

Special care is needed when devising default aspects and weights. Attribute derived values can be prepopulated by community means if applicable.
